@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "170694d538eaaf17e340397bf3a7259170e1282e",
-  "branchName": "release-client-6.3.6",
-  "buildTime": "2025-01-08 04:01:21 GMT",
-  "buildVersion": "1.0.2357",
+  "commitId": "747af1c370e15d18bcdbf2888a996b8345a0846d",
+  "branchName": "release-client-6.4.x",
+  "buildTime": "2025-05-16 06:55:49 GMT",
+  "buildVersion": "1.0.3531",
   "css": [
-    "@zoom/client-calendar-desktop/static/css/chunk-vendors.6fae82dc.css",
-    "@zoom/client-calendar-desktop/static/css/app.f5b0ae41.css"
+    "@zoom/client-calendar-desktop/static/css/chunk-vendors.10970a60.css",
+    "@zoom/client-calendar-desktop/static/css/app.4427c070.css"
   ],
   "js": [
-    "@zoom/client-calendar-desktop/static/js/chunk-vendors.8f2e82ad.js",
-    "@zoom/client-calendar-desktop/static/js/app.6e5f2d3d.js"
+    "@zoom/client-calendar-desktop/static/js/chunk-vendors.9790e7ee.js",
+    "@zoom/client-calendar-desktop/static/js/app.6d675677.js"
   ],
   "key": "@zoom/client-calendar-desktop"
 };
